import { Component, Output, EventEmitter, Input, ElementRef, Renderer2 } from '@angular/core';
import { ModalDismissReasons } from './modal-dismiss-reasons';
import { trigger, transition, style, animate, useAnimation } from '@angular/animations';
import { fadeIn, fadeOut } from '../animations/fade';
import { AnimationsHelper } from '../util/animations-helper';
var NgbModalWindow = (function () {
    function NgbModalWindow(_elRef, _renderer) {
        this._elRef = _elRef;
        this._renderer = _renderer;
        this.backdrop = true;
        this.keyboard = true;
        this.dismissEvent = new EventEmitter();
        this.animationsHelper = new AnimationsHelper();
    }
    NgbModalWindow.prototype.backdropClick = function ($event) {
        if (this.backdrop === true && this._elRef.nativeElement === $event.target) {
            this.dismiss(ModalDismissReasons.BACKDROP_CLICK);
        }
    };
    NgbModalWindow.prototype.escKey = function ($event) {
        if (this.keyboard && !$event.defaultPrevented) {
            this.dismiss(ModalDismissReasons.ESC);
        }
    };
    NgbModalWindow.prototype.dismiss = function (reason) { this.dismissEvent.emit(reason); };
    NgbModalWindow.prototype.ngOnInit = function () {
        this._elWithFocus = document.activeElement;
        this._renderer.addClass(document.body, 'modal-open');
    };
    NgbModalWindow.prototype.ngAfterViewInit = function () {
        if (!this._elRef.nativeElement.contains(document.activeElement)) {
            this._elRef.nativeElement['focus'].apply(this._elRef.nativeElement, []);
        }
    };
    NgbModalWindow.prototype.ngOnDestroy = function () {
        var body = document.body;
        var elWithFocus = this._elWithFocus;
        var elementToFocus;
        if (elWithFocus && elWithFocus['focus'] && body.contains(elWithFocus)) {
            elementToFocus = elWithFocus;
        }
        else {
            elementToFocus = body;
        }
        elementToFocus['focus'].apply(elementToFocus, []);
        this._elWithFocus = null;
        this._renderer.removeClass(body, 'modal-open');
    };
    return NgbModalWindow;
}());
export { NgbModalWindow };
NgbModalWindow.decorators = [
    { type: Component, args: [{
                selector: 'ngb-modal-window',
                host: {
                    '[class]': '"modal fade show" + (windowClass ? " " + windowClass : "")',
                    'role': 'dialog',
                    'tabindex': '-1',
                    'style': 'display: block;',
                    '(keyup.esc)': 'escKey($event)',
                    '(click)': 'backdropClick($event)',
                    '[@modalBackdrop]': 'animationsHelper.state',
                    '(@modalBackdrop.done)': 'animationsHelper.stateChanges.next($event)'
                },
                template: "\n    <div\n      [@modalWindow]=\"animationsHelper.state\"\n      [class]=\"'modal-dialog' + (size ? ' modal-' + size : '')\" \n      role=\"document\">\n        <div class=\"modal-content\"><ng-content></ng-content></div>\n    </div>\n  ",
                animations: [
                    trigger('modalWindow', [
                        transition('void => enter', [
                            style({ transform: 'translate(0, -25%)' }),
                            animate('.3s ease-out', style({ transform: 'translate(0, 0)' }))
                        ]),
                        transition('enter => exit', [
                            style({ transform: 'translate(0, 0)' }),
                            animate('.3s ease-out', style({ transform: 'translate(0, -25%)' }))
                        ])
                    ]),
                    trigger('modalBackdrop', [transition('void => enter', useAnimation(fadeIn)), transition('enter => exit', useAnimation(fadeOut))])
                ]
            },] },
];
/** @nocollapse */
NgbModalWindow.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
NgbModalWindow.propDecorators = {
    'backdrop': [{ type: Input },],
    'keyboard': [{ type: Input },],
    'size': [{ type: Input },],
    'windowClass': [{ type: Input },],
    'dismissEvent': [{ type: Output, args: ['dismiss',] },],
};
//# sourceMappingURL=modal-window.js.map